define(
//begin v1.x content
({
        nomatchMessage: "密码不匹配。",
		badPasswordMessage: "密码无效。"
})

//end v1.x content
);